@rem *********************************************************************
@rem Copyright (c) 2005,2006 IBM Corporation and others.
@rem All rights reserved.   This program and the accompanying materials
@rem are made available under the terms of the Eclipse Public License v1.0
@rem which accompanies this distribution, and is available at
@rem http://www.eclipse.org/legal/epl-v10.html
@rem $Id: gla.bat,v 1.15 2006/07/26 05:36:46 dnsmith Exp $
@rem
@rem Contributors:
@rem IBM - Initial API and implementation
@rem *********************************************************************
@rem
@rem USAGE:  gla <config_file>
@rem PURPOSE:  Execute the Generic Log Adapter (GLA) run-time with the
@rem           specified adapter configuration file to parse one or more log files.
@rem ASSUMPTIONS:  This batch file assumes the GLA run-time and required files are
@rem               stored in the following directory structure:
@rem      %GLA_HOME%\bin    - GLA base batch files
@rem      %GLA_HOME%\config - GLA adapter configuration files
@rem      %GLA_HOME%\lib    - GLA run-time and required jars
@rem      %GLA_HOME%\schema - GLA adapter configuration schema files
@rem INSTRUCTIONS:
@rem     If the GLA run-time and required files are stored as indicated in the
@rem         assumptions section above, change the value of the GLA_HOME
@rem         environment variable to the absolute path where the GLA run-time
@rem         and required files are stored.
@rem         NOTE, if a GLA Language Pack has been installed in the GLA install
@rem         directory then the nl jars will be included in the classpath when
@rem         this batch file is executed.  If the Language Pack is installed
@rem         in another location then add the nl jars to the classpath
@rem         below.  For example, for the Group 1 Language Pack add the following
@rem         jars to the classpath below:
@rem         org.eclipse.hyades.logging.adapter.nl1.jar
@rem         org.eclipse.hyades.logging.core.nl1.jar
@rem         org.eclipse.hyades.logging.parsers.nl1.jar
@rem     If the GLA run-time files are stored in a plug-in (e.g. Eclipse)
@rem         environment, perform the following instructions:
@rem        1) Create a new directory to store the GLA run-time and required files.
@rem        2) Create the bin, config, lib, and schema directories in the new
@rem           directory created in step 1)
@rem        3) Change the value of the GLA_HOME environment variable to the
@rem           absolute path of the new directory created in step 1)
@rem        4) Copy the contents of the scripts directory of
@rem           org.eclipse.hyades.logging.adapter plug-in to the %GLA_HOME%\bin directory.
@rem        4) Copy the contents of the config directory of
@rem           org.eclipse.hyades.logging.parsers plug-in to the %GLA_HOME%\config directory.
@rem        5) Copy the contents of the schema directory of
@rem           org.eclipse.hyades.logging.adapter plug-in to the %GLA_HOME%\schema directory.
@rem        6) Copy the following jar files to the %GLA_HOME%\lib directory
@rem                    Plug-in                 |     JAR
@rem        ---------------------------------------------------
@rem        org.eclipse.hyades.logging.adapter  |  hgla.jar
@rem        org.eclipse.hyades.logging.core     |  hlcbe101.jar
@rem        org.eclipse.hyades.logging.core     |  hlcore.jar
@rem        org.eclipse.hyades.logging.parsers  |  hparse.jar
@rem        org.eclipse.hyades.execution        |  hexr.jar
@rem        eclipse\plugins directory           |  org.eclipse.emf.ecore_2.2.0.jar
@rem        eclipse\plugins directory           |  org.eclipse.emf.common_2.2.0.jar
@rem        eclipse\plugins directory           |  com.ibm.icu_3.4.4.1.jar
@rem
@rem        7) If A TPTP Language Pack has been installed then copy the nl jars
@rem           to the %GLA_HOME%\lib directory and rename them.  For example,
@rem           if the Group 1 Language Pack was installed, copy and rename the
@rem           following jar files to the %GLA_HOME%\lib directory
@rem                    Plug-in JAR                         |     %GLA_HOME%\lib JAR
@rem        -------------------------------------------------------------------------
@rem        org.eclipse.hyades.logging.adapter.nl1\nl1.jar  |  org.eclipse.hyades.logging.adapter.nl1.jar
@rem        org.eclipse.hyades.logging.core\nl1.jar         |  org.eclipse.hyades.logging.core.nl1.jar
@rem        org.eclipse.hyades.logging.parsers.nl1\nl1.jar  |  org.eclipse.hyades.logging.parsers.nl1.jar
@rem

@echo off
@setlocal

SET GLA_HOME=D:\GenericLogAdapter

@rem Build the classpath from the jars in the GLA lib directory
set GLA_CLASSPATH=.
for %%i in ("%GLA_HOME%\lib\*.jar") do call :GLA "%%i"

java -DGLA_HOME="%GLA_HOME%" -classpath %GLA_CLASSPATH% org.eclipse.hyades.logging.adapter.Adapter -ac "%1" -cc "%1"

:GLA
set GLA_CLASSPATH=%GLA_CLASSPATH%;%1

@endlocal