#!/bin/sh
# *********************************************************************
# Copyright (c) 2005,2006 IBM Corporation and others.
# All rights reserved.   This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
# $Id: gla.sh,v 1.13 2006/05/04 14:40:34 dnsmith Exp $
#
# Contributors: 
# IBM - Initial API and implementation
# *********************************************************************
#
# USAGE:  gla.sh <config_file>
# PURPOSE:  Execute the Generic Log Adapter (GLA) run-time with the
#           specified adapter configuration file to parse one or more log files.
# ASSUMPTIONS:  This shell file assumes the GLA run-time and required files are
#               stored in the following directory structure:
#      $GLA_HOME/bin    - GLA base shell files
#      $GLA_HOME/config - GLA adapter configuration files
#      $GLA_HOME/lib    - GLA run-time and required jars
#      $GLA_HOME/schema - GLA adapter configuration schema files
# INSTRUCTIONS:
#     If the GLA run-time and required files are stored as indicated in the
#         assumptions section above, change the value of the GLA_HOME
#         environment variable to the absolute path where the GLA run-time
#         and required files are stored.
#         NOTE, if a GLA Language Pack has been installed then add the nl jars to the
#         classpath below.  For example, for the Group 1 Language Pack add the following
#         to the classpath below:
#         $GLA_HOME/lib/org.eclipse.hyades.logging.adapter.nl1.jar:$GLA_HOME/lib/org.eclipse.hyades.logging.core.nl1.jar:$GLA_HOME/lib/org.eclipse.hyades.logging.parsers.nl1.jar;
#     If the GLA run-time files are stored in a plug-in (e.g. Eclipse)
#         environment, perform the following instructions:
#        1) Create a new directory to store the GLA run-time and required files.
#        2) Create the bin, config, lib, and schema directories in the new
#           directory created in step 1)
#        3) Change the value of the GLA_HOME environment variable to the
#           absolute path of the new directory created in step 1)
#        4) Copy the contents of the scripts directory of
#           org.eclipse.hyades.logging.adapter plug-in to the $GLA_HOME/bin directory.
#        4) Copy the contents of the config directory of
#           org.eclipse.hyades.logging.parsers plug-in to the $GLA_HOME/config directory.
#        5) Copy the contents of the schema directory of
#           org.eclipse.hyades.logging.adapter plug-in to the $GLA_HOME/schema directory.
#        6) Copy the following jar files to the $GLA_HOME/lib directory
#                    Plug-in                 |     JAR
#        ---------------------------------------------------
#        org.eclipse.hyades.logging.adapter  |  hgla.jar
#        org.eclipse.hyades.logging.core     |  hlcbe101.jar
#        org.eclipse.hyades.logging.core     |  hlcore.jar
#        org.eclipse.hyades.logging.parsers  |  hparse.jar
#        org.eclipse.hyades.execution        |  hexr.jar
#        eclipse/plugins directory           |  org.eclipse.emf.ecore_2.2.0.jar
#        eclipse/plugins directory           |  org.eclipse.emf.common_2.2.0.jar
#        eclipse/plugins directory           |  com.ibm.icu_3.4.4.1.jar
#
#        7) Rename the following jar files in the $GLA_HOME/lib directory
#                    Old name             |       New name
#        ---------------------------------------------------
#        org.eclipse.emf.ecore_2.2.0.jar  |  emf.ecore_2.2.0.qualifier.jar
#        org.eclipse.emf.common_2.2.0.jar |  emf.common_2.2.0.qualifier.jar
#
#        8) If A TPTP Language Pack has been installed then copy the nl jars
#           to the $GLA_HOME/lib directory and rename them.  For example,
#           if the Group 1 Language Pack was installed, copy and rename the
#           following jar files to the $GLA_HOME/lib directory
#                    Plug-in JAR                         |     $GLA_HOME/lib JAR
#        -------------------------------------------------------------------------
#        org.eclipse.hyades.logging.adapter.nl1/nl1.jar  |  org.eclipse.hyades.logging.adapter.nl1.jar
#        org.eclipse.hyades.logging.core/nl1.jar         |  org.eclipse.hyades.logging.core.nl1.jar
#        org.eclipse.hyades.logging.parsers.nl1/nl1.jar  |  org.eclipse.hyades.logging.parsers.nl1.jar
#
#          Then add the nl jars to the classpath.  For example, for the Group 1 nl jars add the
#          following to the classpath below:
#     $GLA_HOME/lib/org.eclipse.hyades.logging.adapter.nl1.jar:$GLA_HOME/lib/org.eclipse.hyades.logging.core.nl1.jar:$GLA_HOME/lib/org.eclipse.hyades.logging.parsers.nl1.jar;
#

GLA_HOME=/home/eclipse/GenericLogAdapter
export GLA_HOME

EMF_COMMON=`ls $GLA_HOME/lib/emf.common*`
EMF_ECORE=`ls $GLA_HOME/lib/emf.ecore*`
ICU4J=`ls $GLA_HOME/lib/com.ibm.icu*`

java -DGLA_HOME="$GLA_HOME" -classpath "$GLA_HOME/lib/hparse.jar:$GLA_HOME/lib/hgla.jar:$GLA_HOME/lib/hexr.jar:$GLA_HOME/lib/hlcore.jar:$GLA_HOME/lib/hlcbe101.jar:$EMF_ECORE:$EMF_COMMON:$ICU4J" org.eclipse.hyades.logging.adapter.Adapter -ac "$1" -cc "$1"

